==> chromium-browser_13.0.782.107~r94237.orig.tar.bz2: chromium-13.0.782.107~r94237/src/chrome/app/dummy_main_functions.cc <==
// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "content/common/main_function_params.h"
#include "content/common/result_codes.h"

// Native Client binary for 64-bit Windows can run only the NaCl loader or
// the sandbox broker processes. Other process types are not supported.
int BrowserMain(const MainFunctionParams& parameters) {
  return ResultCodes::BAD_PROCESS_TYPE;
}

int RendererMain(const MainFunctionParams& parameters) {
  return ResultCodes::BAD_PROCESS_TYPE;
}

int PluginMain(const MainFunctionParams& parameters) {
  return ResultCodes::BAD_PROCESS_TYPE;
}

int PpapiPluginMain(const MainFunctionParams& parameters) {
  return ResultCodes::BAD_PROCESS_TYPE;
}

int PpapiBrokerMain(const MainFunctionParams& parameters) {
  return ResultCodes::BAD_PROCESS_TYPE;
}

int WorkerMain(const MainFunctionParams& parameters) {
  return ResultCodes::BAD_PROCESS_TYPE;
}

int UtilityMain(const MainFunctionParams& parameters) {
  return ResultCodes::BAD_PROCESS_TYPE;
}

int ProfileImportMain(const MainFunctionParams& parameters) {
  return ResultCodes::BAD_PROCESS_TYPE;
}

int ZygoteMain(const MainFunctionParams& parameters) {
  return ResultCodes::BAD_PROCESS_TYPE;
}

int DiagnosticsMain(const CommandLine& command_line) {
  return 1;
}

int GpuMain(const MainFunctionParams&) {
  return ResultCodes::BAD_PROCESS_TYPE;
}

int ServiceProcessMain(const MainFunctionParams& parameters) {
  return ResultCodes::BAD_PROCESS_TYPE;
}

==> chromium-browser_14.0.835.202~r103287.orig.tar.bz2: chromium-14.0.835.202~r103287/src/chrome/app/dummy_main_functions.cc <==
// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chrome/common/chrome_result_codes.h"
#include "content/common/main_function_params.h"

// Native Client binary for 64-bit Windows can run only the NaCl loader or
// the sandbox broker processes. Other process types are not supported.
int BrowserMain(const MainFunctionParams& parameters) {
  return chrome::RESULT_CODE_BAD_PROCESS_TYPE;
}

int RendererMain(const MainFunctionParams& parameters) {
  return chrome::RESULT_CODE_BAD_PROCESS_TYPE;
}

int PluginMain(const MainFunctionParams& parameters) {
  return chrome::RESULT_CODE_BAD_PROCESS_TYPE;
}

int PpapiPluginMain(const MainFunctionParams& parameters) {
  return chrome::RESULT_CODE_BAD_PROCESS_TYPE;
}

int PpapiBrokerMain(const MainFunctionParams& parameters) {
  return chrome::RESULT_CODE_BAD_PROCESS_TYPE;
}

int WorkerMain(const MainFunctionParams& parameters) {
  return chrome::RESULT_CODE_BAD_PROCESS_TYPE;
}

int UtilityMain(const MainFunctionParams& parameters) {
  return chrome::RESULT_CODE_BAD_PROCESS_TYPE;
}

int ProfileImportMain(const MainFunctionParams& parameters) {
  return chrome::RESULT_CODE_BAD_PROCESS_TYPE;
}

int ZygoteMain(const MainFunctionParams& parameters) {
  return chrome::RESULT_CODE_BAD_PROCESS_TYPE;
}

int DiagnosticsMain(const CommandLine& command_line) {
  return 1;
}

int GpuMain(const MainFunctionParams&) {
  return chrome::RESULT_CODE_BAD_PROCESS_TYPE;
}

int ServiceProcessMain(const MainFunctionParams& parameters) {
  return chrome::RESULT_CODE_BAD_PROCESS_TYPE;
}
